#[non_exhaustive]pub struct LogExclusion {
pub name: String,
pub description: String,
pub filter: String,
pub disabled: bool,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
Specifies a set of log entries that are filtered out by a sink. If your Google Cloud resource receives a large volume of log entries, you can use exclusions to reduce your chargeable logs. Note that exclusions on organization-level and folder-level sinks don’t apply to child resources. Note also that you cannot modify the _Required sink or exclude logs from it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. A client-assigned identifier, such as
"load-balancer-exclusion". Identifiers are limited to 100 characters and
can include only letters, digits, underscores, hyphens, and periods. First
character has to be alphanumeric.
description: StringOptional. A description of this exclusion.
filter: StringRequired. An advanced logs filter that matches the log entries to be excluded. By using the sample function, you can exclude less than 100% of the matching log entries.
For example, the following query matches 99% of low-severity log entries from Google Cloud Storage buckets:
resource.type=gcs_bucket severity<ERROR sample(insertId, 0.99)
disabled: boolOptional. If set to True, then this exclusion is disabled and it does not exclude any log entries. You can update an exclusion to change the value of this field.
create_time: Option<Timestamp>Output only. The creation timestamp of the exclusion.
This field may not be present for older exclusions.
update_time: Option<Timestamp>Output only. The last update timestamp of the exclusion.
This field may not be present for older exclusions.
Implementations
Sourceimpl LogExclusion
impl LogExclusion
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_disabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_disabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = LogExclusion::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = LogExclusion::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = LogExclusion::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = LogExclusion::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = LogExclusion::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = LogExclusion::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for LogExclusion
impl Clone for LogExclusion
Sourcefn clone(&self) -> LogExclusion
fn clone(&self) -> LogExclusion
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LogExclusion
impl Debug for LogExclusion
Sourceimpl Default for LogExclusion
impl Default for LogExclusion
Sourcefn default() -> LogExclusion
fn default() -> LogExclusion
Sourceimpl Message for LogExclusion
impl Message for LogExclusion
Sourceimpl PartialEq for LogExclusion
impl PartialEq for LogExclusion
impl StructuralPartialEq for LogExclusion