#[non_exhaustive]pub struct TailLogEntriesRequest {
pub resource_names: Vec<String>,
pub filter: String,
pub buffer_window: Option<Duration>,
/* private fields */
}Expand description
The parameters to TailLogEntries.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_names: Vec<String>Required. Name of a parent resource from which to retrieve log entries:
projects/[PROJECT_ID]organizations/[ORGANIZATION_ID]billingAccounts/[BILLING_ACCOUNT_ID]folders/[FOLDER_ID]
May alternatively be one or more views:
projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]
filter: StringOptional. Only log entries that match the filter are returned. An empty
filter matches all log entries in the resources listed in resource_names.
Referencing a parent resource that is not listed in resource_names will
cause the filter to return no results. The maximum length of a filter is
20,000 characters.
buffer_window: Option<Duration>Optional. The amount of time to buffer log entries at the server before being returned to prevent out of order results due to late arriving log entries. Valid values are between 0-60000 milliseconds. Defaults to 2000 milliseconds.
Implementations
Sourceimpl TailLogEntriesRequest
impl TailLogEntriesRequest
Sourcepub fn set_resource_names<T, V>(self, v: T) -> Self
pub fn set_resource_names<T, V>(self, v: T) -> Self
Sets the value of resource_names.
Example
let x = TailLogEntriesRequest::new().set_resource_names(["a", "b", "c"]);Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_buffer_window<T>(self, v: T) -> Self
pub fn set_buffer_window<T>(self, v: T) -> Self
Sets the value of buffer_window.
Example
use wkt::Duration;
let x = TailLogEntriesRequest::new().set_buffer_window(Duration::default()/* use setters */);Sourcepub fn set_or_clear_buffer_window<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_buffer_window<T>(self, v: Option<T>) -> Self
Sets or clears the value of buffer_window.
Example
use wkt::Duration;
let x = TailLogEntriesRequest::new().set_or_clear_buffer_window(Some(Duration::default()/* use setters */));
let x = TailLogEntriesRequest::new().set_or_clear_buffer_window(None::<Duration>);Trait Implementations
Sourceimpl Clone for TailLogEntriesRequest
impl Clone for TailLogEntriesRequest
Sourcefn clone(&self) -> TailLogEntriesRequest
fn clone(&self) -> TailLogEntriesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TailLogEntriesRequest
impl Debug for TailLogEntriesRequest
Sourceimpl Default for TailLogEntriesRequest
impl Default for TailLogEntriesRequest
Sourcefn default() -> TailLogEntriesRequest
fn default() -> TailLogEntriesRequest
Sourceimpl Message for TailLogEntriesRequest
impl Message for TailLogEntriesRequest
Sourceimpl PartialEq for TailLogEntriesRequest
impl PartialEq for TailLogEntriesRequest
impl StructuralPartialEq for TailLogEntriesRequest