#[non_exhaustive]pub struct UpdateCmekSettingsRequest {
pub name: String,
pub cmek_settings: Option<CmekSettings>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
The parameters to UpdateCmekSettings.
See Enabling CMEK for Log Router for more information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name for the CMEK settings to update.
"projects/[PROJECT_ID]/cmekSettings"
"organizations/[ORGANIZATION_ID]/cmekSettings"
"billingAccounts/[BILLING_ACCOUNT_ID]/cmekSettings"
"folders/[FOLDER_ID]/cmekSettings"For example:
"organizations/12345/cmekSettings"
Note: CMEK for the Log Router can currently only be configured for Google Cloud organizations. Once configured, it applies to all projects and folders in the Google Cloud organization.
cmek_settings: Option<CmekSettings>Required. The CMEK settings to update.
See Enabling CMEK for Log Router for more information.
update_mask: Option<FieldMask>Optional. Field mask identifying which fields from cmek_settings should
be updated. A field will be overwritten if and only if it is in the update
mask. Output only fields cannot be updated.
See FieldMask for more information.
For example: "updateMask=kmsKeyName"
Implementations
Sourceimpl UpdateCmekSettingsRequest
impl UpdateCmekSettingsRequest
Sourcepub fn set_cmek_settings<T>(self, v: T) -> Selfwhere
T: Into<CmekSettings>,
pub fn set_cmek_settings<T>(self, v: T) -> Selfwhere
T: Into<CmekSettings>,
Sets the value of cmek_settings.
Example
use google_cloud_logging_v2::model::CmekSettings;
let x = UpdateCmekSettingsRequest::new().set_cmek_settings(CmekSettings::default()/* use setters */);Sourcepub fn set_or_clear_cmek_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<CmekSettings>,
pub fn set_or_clear_cmek_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<CmekSettings>,
Sets or clears the value of cmek_settings.
Example
use google_cloud_logging_v2::model::CmekSettings;
let x = UpdateCmekSettingsRequest::new().set_or_clear_cmek_settings(Some(CmekSettings::default()/* use setters */));
let x = UpdateCmekSettingsRequest::new().set_or_clear_cmek_settings(None::<CmekSettings>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateCmekSettingsRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateCmekSettingsRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateCmekSettingsRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateCmekSettingsRequest
impl Clone for UpdateCmekSettingsRequest
Sourcefn clone(&self) -> UpdateCmekSettingsRequest
fn clone(&self) -> UpdateCmekSettingsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateCmekSettingsRequest
impl Debug for UpdateCmekSettingsRequest
Sourceimpl Default for UpdateCmekSettingsRequest
impl Default for UpdateCmekSettingsRequest
Sourcefn default() -> UpdateCmekSettingsRequest
fn default() -> UpdateCmekSettingsRequest
Sourceimpl Message for UpdateCmekSettingsRequest
impl Message for UpdateCmekSettingsRequest
impl StructuralPartialEq for UpdateCmekSettingsRequest