#[non_exhaustive]pub struct UpdateSettingsRequest {
pub name: String,
pub settings: Option<Settings>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
The parameters to UpdateSettings.
See Enabling CMEK for Log Router for more information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name for the settings to update.
"organizations/[ORGANIZATION_ID]/settings"For example:
"organizations/12345/settings"
Note: Settings for the Log Router can currently only be configured for Google Cloud organizations. Once configured, it applies to all projects and folders in the Google Cloud organization.
settings: Option<Settings>Required. The settings to update.
See Enabling CMEK for Log Router for more information.
update_mask: Option<FieldMask>Optional. Field mask identifying which fields from settings should
be updated. A field will be overwritten if and only if it is in the update
mask. Output only fields cannot be updated.
See FieldMask for more information.
For example: "updateMask=kmsKeyName"
Implementations
Sourceimpl UpdateSettingsRequest
impl UpdateSettingsRequest
Sourcepub fn set_settings<T>(self, v: T) -> Self
pub fn set_settings<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_settings<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_settings<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateSettingsRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateSettingsRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateSettingsRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateSettingsRequest
impl Clone for UpdateSettingsRequest
Sourcefn clone(&self) -> UpdateSettingsRequest
fn clone(&self) -> UpdateSettingsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateSettingsRequest
impl Debug for UpdateSettingsRequest
Sourceimpl Default for UpdateSettingsRequest
impl Default for UpdateSettingsRequest
Sourcefn default() -> UpdateSettingsRequest
fn default() -> UpdateSettingsRequest
Sourceimpl Message for UpdateSettingsRequest
impl Message for UpdateSettingsRequest
Sourceimpl PartialEq for UpdateSettingsRequest
impl PartialEq for UpdateSettingsRequest
impl StructuralPartialEq for UpdateSettingsRequest